@@ -14,15 +14,7 @@
 // this program; if not, see <http://www.gnu.org/licenses/>.
 
 #include <octave/oct.h>
-
-#if 0
 #include <octave/file-io.h>
-#else
-// The following declaration moved from pt-plot.h to file-io.h
-// We duplicate it here so that octave-forge can support earlier
-// versions of octave.  This is cruft that needs to be removed.
-extern void mark_for_deletion (const std::string&);
-#endif
 
 DEFUN_DLD (mark_for_deletion, args,,
 "mark_for_deletion ( filename1, filename2, ... );\n\
